# norman-ml

**Status: Under Development**

This is a placeholder package for the Norman AI ML. The package is currently under active development.

## Coming Soon

The Norman ML will provide tools and utilities for interacting with Norman AI services.

Stay tuned for updates!

## License

Copyright © Norman Artificial Intelligence LTD. Licensed under the Apache License 2.0.